summaryrefslogtreecommitdiffstats
path: root/src/DeadlockDetect.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/DeadlockDetect.h')
-rw-r--r--src/DeadlockDetect.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/src/DeadlockDetect.h b/src/DeadlockDetect.h
index 39d3f8691..ee97fd6f7 100644
--- a/src/DeadlockDetect.h
+++ b/src/DeadlockDetect.h
@@ -59,8 +59,10 @@ protected:
/** Checks if the world's age has changed, updates the world's stats; calls DeadlockDetected() if deadlock detected */
void CheckWorldAge(const AString & a_WorldName, Int64 a_Age);
- /** Called when a deadlock is detected. Aborts the server. */
- NORETURN void DeadlockDetected(void);
+ /** Called when a deadlock is detected in a world. Aborts the server.
+ a_WorldName is the name of the world whose age has triggered the detection.
+ a_WorldAge is the age (in ticks) in which the world is stuck. */
+ NORETURN void DeadlockDetected(const AString & a_WorldName, Int64 a_WorldAge);
} ;